#
# spec file for package hut
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           hut
Version:        0.5.0
Release:        1.4
Summary:        A CLI tool for sr.ht
License:        AGPL-3.0-or-later
Group:          Development/Tools/Navigators
URL:            https://sr.ht/~xenrox/hut
Source0:        https://git.sr.ht/~xenrox/hut/archive/v%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.17
BuildRequires:  golang-packaging
BuildRequires:  scdoc
%{go_nostrip}

%description
hut is a CLI companion utility to interact with sr.ht.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
The official bash completion script for hut.

%package fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       fish
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
The official fish completion script for hut.

%package zsh-completion
Summary:        ZSH Completion for %{name}
Group:          System/Shells
Requires:       zsh
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
The official zsh completion script for hut.

%prep
%autosetup -p1 -a1 -n %{name}-v%{version}

%build
make GOFLAGS='-mod=vendor -buildmode=pie -ldflags=-s'

%install
%make_install PREFIX=%{_prefix}

%check
go test -v

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%_mandir/man1/%{name}.1%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion

%files fish-completion
%{_datadir}/fish

%files zsh-completion
%{_datadir}/zsh

%changelog
* Sat Jun  8 2024 Matej Cepl <mcepl@cepl.eu>
- Change upstream to the new location https://sr.ht/~xenrox/hut
- Update to version 0.5.0:
  - Upgrade dependencies
  - Update GraphQL schema
  - Upgrade hg schema
  - export/lists: add visibility
  - export/paste: ignore empty filenames
  - export/meta: write info.json file
  - export: fix writeExportStamp return value
  - client: remove unused Client.Hostname
  - import: accept multiple directories
  - config: use scfg decoder to read config file
  - todo ticket edit: new command
  - todo ticket list: Add status filtering
  - pager/editor: Use shlex to parse command
  - export/git: add readme and head
  - export/hg: add readme and nonPublishing
  - Add the import command
  - export: Support specifying services and resources
  - import: Fix wrong import path
- At least pretend we run some tests (there is almost no test
  coverage upstream).
- I believe _service should have all tests to "manual", not
  "localonly".
* Tue Dec 19 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 0.4.0
  * Pagination is now supported for all commands.
  * todo trackers can now be exported.
  * Comments are now displayed when showing a todo ticket.
  * Sharing builds secrets is now supported.
  * A new command to display lists subscriptions has been added.
  * The graphql command can perform file uploads.
* Thu Apr 13 2023 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Update to version 0.3.0
  * Pagination is now supported across the board.
  * Improved support for Web hooks.
  * builds: add --edit to adjust build manifests using an editor
    before submitting, add artifacts sub-command, improve support
    for labels.
  * todo: add sub-command to create a new ticket and show a ticket.
  * git: add sub-command to update repository settings.
  * pages: the publish sub-command can now take directories as
    input and supports advanced site configuration.
  * lists: add sub-command to fetch archives.
- Fetch dependencies via service
* Sun Aug 14 2022 Jan-Luca Kiok <me@jlk.one>
- Correct bash completion package Supplements
- Specify shell completion package group
* Thu Jul 28 2022 Jan-Luca Kiok <me@jlk.one>
- Update to version 0.2.0
  * Add various user-webhooks
  * Add various tracker webhooks
  * Add ticket webhooks
  * Add various create and delete actions
  * Implement user-webhook ID completions
  * Fix broken endpoints
  * Add missing completions
  * Improve output of list commands
  * Update outdated schemas
  * export: new subcommand
  * lists patchset show: new subcommand
  * builds: Improve secret list output
* Sun Apr 17 2022 Jan-Luca Kiok <me@jlk.one>
- Update to version 0.1.0
  * First public release
  * Every major action across public services supported
* Sat Apr  9 2022 Jan-Luca Kiok <me@jlk.one>
- Use direct shell commands instead of indirect macros within the
  specfile
* Thu Apr  7 2022 Jan-Luca Kiok <me@jlk.one>
- Format spec file via osc service
* Tue Mar  8 2022 Jan-Luca Kiok <me@jlk.one>
- Update to latest master (Commit 70566f2)
- Rename release to 0 for now
* Mon Feb 28 2022 Jan-Luca Kiok <me@jlk.one>
- Update to latest master (Commit b12d9554)
- Package shell completions in own packages
- Use macro for make
- Do not hardcode prefix
* Sat Jan 15 2022 JL K <me@jlk.one>
- Bump to go version 1.17 only
* Sat Jan 15 2022 JL K <me@jlk.one>
- Init
